@@ -13,7 +13,7 @@ import pytest
 from metpy.plots import Hodograph, SkewT
 from metpy.units import units
 
-MPL_VERSION = matplotlib.__version__[:3]
+MPL_VERSION = matplotlib.__version__[:5]
 
 
 @pytest.mark.mpl_image_compare(remove_text=True, style='default', tolerance=0.069)
@@ -156,8 +156,8 @@ def test_skewt_units():
     skew.ax.axvline(-10, color='orange')
 
     # On Matplotlib <= 3.6, ax[hv]line() doesn't trigger unit labels
-    assert skew.ax.get_xlabel() == ('degree_Celsius' if MPL_VERSION > '3.6' else '')
-    assert skew.ax.get_ylabel() == ('hectopascal' if MPL_VERSION > '3.6' else '')
+    assert skew.ax.get_xlabel() == ('degree_Celsius' if MPL_VERSION == '3.7.0' else '')
+    assert skew.ax.get_ylabel() == ('hectopascal' if MPL_VERSION == '3.7.0' else '')
 
     # Clear them for the image test
     skew.ax.set_xlabel('')
@@ -319,7 +319,8 @@ def test_hodograph_api():
     return fig
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.6 if MPL_VERSION == '3.3' else 0.)
+@pytest.mark.mpl_image_compare(remove_text=True,
+                               tolerance=0.6 if MPL_VERSION.startswith('3.3') else 0.)
 def test_hodograph_units():
     """Test passing quantities to Hodograph."""
     fig = plt.figure(figsize=(9, 9))
